package com.datacloudsec.scan.service.impl;

import com.datacloudsec.scan.common.Constant;
import com.datacloudsec.scan.dao.AlarmlogMapper;
import com.datacloudsec.scan.service.IAlarmlog;
import com.datacloudsec.scan.service.IDevice;
import com.datacloudsec.utils.DataRule;
import com.datacloudsec.utils.InstanceUtil;
import com.datacloudsec.utils.ObjectUtil;
import com.datacloudsec.utils.PoiExcelUtils;
import com.datacloudsec.utils.ReflectUtils;
import com.google.common.collect.Iterables;
import java.io.File;
import java.io.FileOutputStream;
import java.util.List;
import java.util.Map;
import javax.servlet.http.HttpSession;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.io.FileUtils;
import org.apache.commons.io.IOUtils;
import org.apache.poi.hssf.usermodel.HSSFCell;
import org.apache.poi.hssf.usermodel.HSSFCellStyle;
import org.apache.poi.hssf.usermodel.HSSFRow;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;

/* loaded from: com_datacloudsec_scan_service_impl.jar:com/datacloudsec/scan/service/impl/AlarmlogService.class */
public class AlarmlogService implements IAlarmlog {
    private AlarmlogMapper alarmlog = (AlarmlogMapper) InstanceUtil.newDaoInstance(AlarmlogMapper.class);

    public List<Map<String, Object>> search(HttpSession session, String name, String ip, Integer devtype, Integer alarmtype, Integer readflag, String sdate, String edate, Integer offset, Integer limit) throws Exception {
        return this.alarmlog.search(name, ip, devtype, alarmtype, readflag, sdate, edate, DataRule.getRuleWhere(session, "t_task"), offset, limit);
    }

    public Integer searchCount(HttpSession session, String name, String ip, Integer devtype, Integer alarmtype, Integer readflag, String sdate, String edate) throws Exception {
        return Integer.valueOf(this.alarmlog.searchCount(name, ip, devtype, alarmtype, readflag, sdate, edate, DataRule.getRuleWhere(session, "t_task")));
    }

    public int setReadflag(Integer readflag, Integer id) throws Exception {
        return this.alarmlog.setReadflag(readflag, id);
    }

    public int delete(Integer id) throws Exception {
        return this.alarmlog.delete(id);
    }

    public File export(HttpSession session, String name, String ip, Integer devtype, Integer alarmtype, String sdate, String edate) throws Exception {
        HSSFWorkbook hssfWorkbook = writeContent(session, name, ip, devtype, alarmtype, sdate, edate);
        File f = new File(Constant.TEMP_DIR, String.valueOf(System.currentTimeMillis()) + ".xls");
        FileOutputStream out = null;
        try {
            try {
                out = FileUtils.openOutputStream(f);
                hssfWorkbook.write(out);
                IOUtils.closeQuietly(out);
                return f;
            } catch (Exception e) {
                throw e;
            }
        } catch (Throwable th) {
            IOUtils.closeQuietly(out);
            throw th;
        }
    }

    private HSSFWorkbook writeContent(HttpSession session, String name, String ip, Integer devtype, Integer alarmtype, String sdate, String edate) throws Exception {
        Object valueOfGetIncludeObjectFeild;
        String[] headers = {"漏洞名称@name@12000", "资产IP/URL@ip@12000", "任务名称@taskname@8000", "资产类型@devtype@4000", "告警类型@alarmtype@4000", "漏洞等级@level@4000", "时间@time@8000"};
        PoiExcelUtils poiExcelUtil = new PoiExcelUtils();
        HSSFWorkbook hssfWorkbook = poiExcelUtil.getHSSFWorkbook();
        List<Map<String, Object>> devData = this.alarmlog.search(name, ip, devtype, alarmtype, (Integer) null, sdate, edate, DataRule.getRuleWhere(session, "t_task"), (Integer) null, (Integer) null);
        Iterable<List<Map<String, Object>>> data = Iterables.partition(devData, 1000);
        int num = 1;
        for (List<Map<String, Object>> dataList : data) {
            HSSFSheet hssfSheet = poiExcelUtil.getHSSFSheet(hssfWorkbook, "告警日志" + num);
            poiExcelUtil.writeHeader(hssfWorkbook, hssfSheet, headers, "告警日志" + num);
            int rownum = 2;
            HSSFCellStyle cellStyle = poiExcelUtil.createContentCellStyle(hssfWorkbook);
            if (!CollectionUtils.isEmpty(dataList)) {
                int size = dataList.size();
                for (int j = 0; j < size; j++) {
                    HSSFRow row = hssfSheet.createRow(rownum);
                    Map<String, Object> map = dataList.get(j);
                    int len = headers.length;
                    for (int i = 0; i < len; i++) {
                        HSSFCell cell = row.createCell(i);
                        String key = ObjectUtil.getString(headers[i].split("@")[1].trim(), "");
                        if (map != null) {
                            if ("devtype".equalsIgnoreCase(key)) {
                                valueOfGetIncludeObjectFeild = IDevice.TASK_DEVICE_TYPE.get(new StringBuilder().append(map.get(key)).toString());
                            } else if ("alarmtype".equalsIgnoreCase(key)) {
                                valueOfGetIncludeObjectFeild = ALARM_TYPE.get(map.get(key));
                            } else if ("level".equalsIgnoreCase(key)) {
                                valueOfGetIncludeObjectFeild = LEVEL.get(map.get(key));
                            } else {
                                valueOfGetIncludeObjectFeild = map.get(key);
                            }
                        } else {
                            valueOfGetIncludeObjectFeild = ReflectUtils.getValueOfGetIncludeObjectFeild(dataList.get(j), key);
                        }
                        Object cellValue = valueOfGetIncludeObjectFeild;
                        poiExcelUtil.cellValueHandler(cell, cellValue);
                        cell.setCellStyle(cellStyle);
                    }
                    rownum++;
                }
            }
            num++;
        }
        return hssfWorkbook;
    }
}
